@@ -4,9 +4,9 @@
 say something ....
 '''
 
-from epidemix.utils.plot import *
-from epidemix.utils.partition import *
+# from epidemix.utils.plot import *
+# from epidemix.utils.partition import *
 
-__version__ = "1.1.1"
+__version__ = "1.1.2"
 
 ########################################################################
